@@ -1,5 +1,12 @@
 from uuid import UUID
 
+UUID_SERVICE = UUID("{0000180a-0000-1000-8000-00805f9b34fb}")
+MODEL_NUMBER = UUID("{00002a24-0000-1000-8000-00805f9b34fb}")
+FIRMWARE_VERSION = UUID("{00002a26-0000-1000-8000-00805f9b34fb}")
+HARDWARE_VERSION = UUID("{00002a27-0000-1000-8000-00805f9b34fb}")
+SOFTWARE_VERSION = UUID("{00002a28-0000-1000-8000-00805f9b34fb}")
+MANUFACTURER_NAME = UUID("{00002a29-0000-1000-8000-00805f9b34fb}")
+
 DEVICE_NAME = UUID("{b85fa07a-9382-4838-871c-81d045dcc2ff}")
 DEVICE_STATUS = UUID("{528b80e8-c47a-4c0a-bdf1-916a7748f412}")
 
